Documentation
¶
Overview ¶
Package say returns friendly statements
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Goodbye ¶
func Goodbye() string
Goodbye returns the infomous Lawrence Oates quote
Example ¶
package main
import (
"fmt"
"github.com/cadamus/say/v2"
)
func main() {
fmt.Println(say.Goodbye())
}
Output: I am just going outside and I may be some time
func Hello ¶
Hello returns the "hello, {name}!" greeting. If name is the empty string, name will default to World, returning the famous hello, World! greeting.
Example ¶
package main
import (
"fmt"
"github.com/cadamus/say/v2"
)
func main() {
fmt.Println(say.Hello(""))
}
Output: hello, World!
Example (WithName) ¶
package main
import (
"fmt"
"github.com/cadamus/say/v2"
)
func main() {
fmt.Println(say.Hello("Golang"))
}
Output: hello, Golang!
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.